@@ -5,7 +5,7 @@
  * Copyright (C) 2005 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -546,7 +546,7 @@ e_book_backend_vcf_stop_book_view (EBookBackend  *backend,
 static char *
 e_book_backend_vcf_extract_path_from_uri (const char *uri)
 {
-	g_assert (strncasecmp (uri, "vcf://", 6) == 0);
+	g_assert (g_ascii_strncasecmp (uri, "vcf://", 6) == 0);
 
 	return g_strdup (uri + 6);
 }
