@@ -92,7 +92,8 @@ static void e_cal_backend_file_finalize (GObject *object);
 
 static ECalBackendSyncClass *parent_class;
 
-
+static ECalBackendSyncStatus
+e_cal_backend_file_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj);
 
 /* g_hash_table_foreach() callback to destroy a ECalBackendFileObject */
 static void
@@ -689,6 +690,8 @@ notify_removals_cb (gpointer key, gpointer value, gpointer data)
 	if (!g_hash_table_lookup (context->new_uid_hash, uid)) {
 		icalcomponent *old_icomp;
 		gchar *old_obj_str;
+		ECalComponent *comp; 
+		ECalComponentId *id;
 
 		/* Object was removed */
 
@@ -699,8 +702,15 @@ notify_removals_cb (gpointer key, gpointer value, gpointer data)
 		old_obj_str = icalcomponent_as_ical_string (old_icomp);
 		if (!old_obj_str)
 			return;
+		
+		comp = e_cal_component_new_from_string (old_obj_str);
+		id = e_cal_component_get_id (comp);
+		
 
-		e_cal_backend_notify_object_removed (context->backend, uid, old_obj_str, NULL);
+		e_cal_backend_notify_object_removed (context->backend, id, old_obj_str, NULL);
+	
+		e_cal_component_free_id (id);
+		g_object_unref (comp);
 	}
 }
 
@@ -886,6 +896,9 @@ e_cal_backend_file_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_
 			status = create_cal (cbfile, str_uri);
 	}
 
+	if (status == GNOME_Evolution_Calendar_Success)
+		e_cal_backend_file_add_timezone (backend, cal, (const char *) icaltimezone_get_tzid (priv->default_zone));
+
 	g_free (str_uri);
 
 	return status;
@@ -1166,20 +1179,12 @@ e_cal_backend_file_set_default_timezone (ECalBackendSync *backend, EDataCal *cal
 {
 	ECalBackendFile *cbfile;
 	ECalBackendFilePrivate *priv;
-	icaltimezone *zone;
 
 	cbfile = E_CAL_BACKEND_FILE (backend);
 	priv = cbfile->priv;
 
-	g_return_val_if_fail (priv->icalcomp != NULL, GNOME_Evolution_Calendar_NoSuchCal);
-
-	/* Look up the VTIMEZONE in our icalcomponent. */
-	zone = icalcomponent_get_timezone (priv->icalcomp, tzid);
-	if (!zone)
-		return GNOME_Evolution_Calendar_ObjectNotFound;
-
 	/* Set the default timezone to it. */
-	priv->default_zone = zone;
+	priv->default_zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
 
 	return GNOME_Evolution_Calendar_Success;
 }
@@ -2382,6 +2387,7 @@ e_cal_backend_file_receive_objects (ECalBackendSync *backend, EDataCal *cal, con
 			break;
 		case ICAL_METHOD_CANCEL:
 			if (cancel_received_object (cbfile, subcomp)) {
+				ECalComponentId *id;
 				object = (char *) icalcomponent_as_ical_string (subcomp);
 				obj_data = g_hash_table_lookup (priv->comp_uid_hash, uid);
 				if (obj_data)
@@ -2389,11 +2395,14 @@ e_cal_backend_file_receive_objects (ECalBackendSync *backend, EDataCal *cal, con
 				else
 					old_object = NULL;
 
-				e_cal_backend_notify_object_removed (E_CAL_BACKEND (backend), uid, old_object, object);
+				id = e_cal_component_get_id (comp);
+
+				e_cal_backend_notify_object_removed (E_CAL_BACKEND (backend), id, old_object, object);
 
 				/* remove the component from the toplevel VCALENDAR */
 				icalcomponent_remove_component (toplevel_comp, subcomp);
 				icalcomponent_free (subcomp);
+				e_cal_component_free_id (id);
 
 				g_free (old_object);
 			}
