@@ -50,7 +50,7 @@ static gboolean groupwise_send_to (CamelTransport *transport,
 				  CamelAddress *recipients,
 				  CamelException *ex);
 
-static gboolean groupwise_connect (CamelService *service, CamelException *ex);
+static gboolean groupwise_transport_connect (CamelService *service, CamelException *ex);
 static char *groupwise_transport_get_name (CamelService *service, gboolean brief);
 static void groupwise_transport_construct (CamelService *service, CamelSession *session,
 					   CamelProvider *provider, CamelURL *url, CamelException *ex);
@@ -71,7 +71,7 @@ camel_groupwise_transport_class_init (CamelGroupwiseTransportClass *camel_groupw
 	
 	parent_class = CAMEL_TRANSPORT_CLASS (camel_type_get_global_classfuncs (camel_transport_get_type ()));
 	
-	camel_service_class->connect = groupwise_connect;
+	camel_service_class->connect = groupwise_transport_connect;
 	camel_service_class->get_name = groupwise_transport_get_name;
 	camel_service_class->construct = groupwise_transport_construct;
 	
@@ -127,7 +127,7 @@ static char *groupwise_transport_get_name (CamelService *service, gboolean brief
 
 
 static gboolean
-groupwise_connect (CamelService *service, CamelException *ex)
+groupwise_transport_connect (CamelService *service, CamelException *ex)
 {
 	return TRUE;
 
@@ -162,6 +162,7 @@ groupwise_send_to (CamelTransport *transport,
 
 	/*camel groupwise store and cnc*/
 	store = camel_session_get_store (service->session, url, ex );
+	g_free (url);
 	if (!store) {
 		g_warning ("ERROR: Could not get a pointer to the store");
 		camel_exception_set (ex, CAMEL_EXCEPTION_STORE_INVALID, _("Cannot get folder: Invalid operation on this store"));
@@ -172,7 +173,7 @@ groupwise_send_to (CamelTransport *transport,
 
 	cnc = cnc_lookup (priv);
 	if (!cnc) {
-		g_error ("||| Eh!!! Failure |||\n");
+		g_warning ("||| Eh!!! Failure |||\n");
 		camel_operation_end (NULL);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE, _("Authentication failed"));
 		return FALSE;
@@ -208,7 +209,13 @@ groupwise_send_to (CamelTransport *transport,
 		g_object_unref (item);
 		if (temp_item)
 			g_object_unref (temp_item);
-		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE, _("Unknown error"));
+
+		/* FIXME: 58652 should be changed with an enum.*/
+		if (status == 58652)
+			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE, _("You have exceed this account's storage limit. Your messages are queued in Outbox. Try sending after deleting/archiving some mails.\n"));
+		else
+			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,_("Could not send message: %s"),_("Unknown error"));
+
 		return FALSE;
 	}
 	e_gw_item_set_link_info (item, NULL);
