@@ -68,6 +68,14 @@
 #define IMAP_PORT "143"
 #define IMAPS_PORT "993"
 
+#ifdef G_OS_WIN32
+/* The strtok() in Microsoft's C library is MT-safe (but still uses
+ * only one buffer pointer per thread, but for the use of strtok_r()
+ * here that's enough).
+ */
+#define strtok_r(s,sep,lasts) (*(lasts)=strtok((s),(sep)))
+#endif
+
 static CamelDiscoStoreClass *parent_class = NULL;
 
 static char imap_tag_prefix = 'A';
@@ -746,6 +754,10 @@ connect_to_server (CamelService *service, struct addrinfo *ai, int ssl_mode, Cam
 	return FALSE;
 }
 
+#ifndef G_OS_WIN32
+
+/* Using custom commands to connect to IMAP servers is not supported on Win32 */
+
 static gboolean
 connect_to_server_process (CamelService *service, const char *cmd, CamelException *ex)
 {
@@ -889,6 +901,8 @@ connect_to_server_process (CamelService *service, const char *cmd, CamelExceptio
 	
 }
 
+#endif
+
 static struct {
 	char *value;
 	char *serv;
@@ -905,16 +919,19 @@ static struct {
 static gboolean
 connect_to_server_wrapper (CamelService *service, CamelException *ex)
 {
-	const char *command, *ssl_mode;
+	const char *ssl_mode;
 	struct addrinfo hints, *ai;
 	int mode, ret, i;
 	char *serv;
 	const char *port;
 
+#ifndef G_OS_WIN32
+	const char *command;
+
 	if (camel_url_get_param(service->url, "use_command")
 	    && (command = camel_url_get_param(service->url, "command")))
 		return connect_to_server_process(service, command, ex);
-	
+#endif	
 	if ((ssl_mode = camel_url_get_param (service->url, "use_ssl"))) {
 		for (i = 0; ssl_options[i].value; i++)
 			if (!strcmp (ssl_options[i].value, ssl_mode))
@@ -1619,19 +1636,13 @@ static void
 imap_noop (CamelStore *store, CamelException *ex)
 {
 	CamelImapStore *imap_store = (CamelImapStore *) store;
-	CamelDiscoStore *disco = (CamelDiscoStore *) store;
 	CamelImapResponse *response;
 	CamelFolder *current_folder;
 	
-	if (camel_disco_store_status (disco) != CAMEL_DISCO_STORE_ONLINE)
-		return;
-	
 	CAMEL_SERVICE_LOCK (imap_store, connect_lock);
 
-	if (!camel_imap_store_connected(imap_store, ex)) {
-		CAMEL_SERVICE_UNLOCK(imap_store, connect_lock);
-		return;
-	}
+	if (!camel_imap_store_connected(imap_store, ex))
+		goto done;
 
 	current_folder = imap_store->current_folder;
 	if (current_folder && imap_summary_is_dirty (current_folder->summary)) {
@@ -1642,7 +1653,7 @@ imap_noop (CamelStore *store, CamelException *ex)
 		if (response)
 			camel_imap_response_free (imap_store, response);
 	}
-	
+done:
 	CAMEL_SERVICE_UNLOCK (imap_store, connect_lock);
 }
 
@@ -2845,15 +2856,15 @@ subscribe_folder (CamelStore *store, const char *folder_name,
 	CamelFolderInfo *fi;
 	CamelStoreInfo *si;
 
-	if (!camel_disco_store_check_online (CAMEL_DISCO_STORE (store), ex))
-		return;
+	CAMEL_SERVICE_LOCK(store, connect_lock);
+
 	if (!camel_imap_store_connected (imap_store, ex))
-		return;
+		goto done;
 	
 	response = camel_imap_command (imap_store, NULL, ex,
 				       "SUBSCRIBE %F", folder_name);
 	if (!response)
-		return;
+		goto done;
 	camel_imap_response_free (imap_store, response);
 	
 	si = camel_store_summary_path((CamelStoreSummary *)imap_store->summary, folder_name);
@@ -2870,7 +2881,7 @@ subscribe_folder (CamelStore *store, const char *folder_name,
 		/* we don't need to emit a "folder_subscribed" signal
                    if we are in the process of renaming folders, so we
                    are done here... */
-		return;
+		goto done;
 	}
 
 	fi = imap_build_folder_info(imap_store, folder_name);
@@ -2878,6 +2889,8 @@ subscribe_folder (CamelStore *store, const char *folder_name,
 	
 	camel_object_trigger_event (CAMEL_OBJECT (store), "folder_subscribed", fi);
 	camel_folder_info_free (fi);
+done:
+	CAMEL_SERVICE_UNLOCK(store, connect_lock);
 }
 
 static void
@@ -2886,19 +2899,21 @@ unsubscribe_folder (CamelStore *store, const char *folder_name,
 {
 	CamelImapStore *imap_store = CAMEL_IMAP_STORE (store);
 	CamelImapResponse *response;
+
+	CAMEL_SERVICE_LOCK(store, connect_lock);
 	
-	if (!camel_disco_store_check_online (CAMEL_DISCO_STORE (store), ex))
-		return;
 	if (!camel_imap_store_connected (imap_store, ex))
-		return;
+		goto done;
 	
 	response = camel_imap_command (imap_store, NULL, ex,
 				       "UNSUBSCRIBE %F", folder_name);
 	if (!response)
-		return;
+		goto done;
 	camel_imap_response_free (imap_store, response);
 
 	imap_folder_effectively_unsubscribed (imap_store, folder_name, ex);
+done:
+	CAMEL_SERVICE_UNLOCK(store, connect_lock);
 }
 
 #if 0
@@ -2953,7 +2968,7 @@ ssize_t
 camel_imap_store_readline (CamelImapStore *store, char **dest, CamelException *ex)
 {
 	CamelStreamBuffer *stream;
-	char linebuf[1024];
+	char linebuf[1024] = {0};
 	GByteArray *ba;
 	ssize_t nread;
 	
