@@ -4,7 +4,7 @@
  * Copyright (C) 2003  Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -114,7 +114,7 @@ impl_dispose (GObject *object)
 /* Initialization.  */
 
 static void
-class_init (ESourceClass *class)
+e_source_class_init (ESourceClass *class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
@@ -134,7 +134,7 @@ class_init (ESourceClass *class)
 }
 
 static void
-init (ESource *source)
+e_source_init (ESource *source)
 {
 	ESourcePrivate *priv;
 
@@ -155,11 +155,11 @@ e_source_get_type (void)
                         sizeof (ESourceClass),
                         (GBaseInitFunc) NULL,
                         (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) class_init,
+                        (GClassInitFunc) e_source_class_init,
                         NULL, NULL,
                         sizeof (ESource),
                         0,
-                        (GInstanceInitFunc) init
+                        (GInstanceInitFunc) e_source_init
                 };
 		e_source_type = g_type_register_static (G_TYPE_OBJECT, "ESource", &info, 0);
 	}
